==> mupad-1.4.2.tgz: mupad/share/mmg/include/kernel/MGR_color.h <==
/*
 * Datei:      MGR_color.h
 *
 * Inhalt:     Diese Datei enth"alt die Deklaration aller
 *             Funktionen, die zur Evaluierung einer benut-
 *             zerdefinierten Farbfunktion implementiert
 *             wurden.
 *
 * Autor:      Thorsten Schulze
 *
 * Datum:      12.02.1994
 */

#ifndef __MGR_color__
#define __MGR_color__


/*
 * Konstanten
 */

#define        MGRC_CURVE_2D     0L
#define        MGRC_CURVE_3D     1L
#define        MGRC_SURFACE      2L
#define        MGRC_LIST_2D      3L
#define        MGRC_LIST_3D      4L

#ifndef GRAPHIC 

/*
 * Makros
 */

#define         MGRM_color_curve_2d(mode, object, sp_cfun, x, y, u, this_color) \
                MGR_color_eval_color(mode, object, sp_cfun, x, y, MMMNULL, u, MMMNULL, this_color);

#define         MGRM_color_list_2d(mode, object, sp_cfun, x, y, this_color) \
                MGR_color_eval_color(mode, object, sp_cfun, x, y, MMMNULL, MMMNULL, MMMNULL, this_color);

#define         MGRM_color_curve_3d(mode, object, sp_cfun, x, y, z, u, this_color) \
                MGR_color_eval_color(mode, object, sp_cfun, x, y, z, u, MMMNULL, this_color);

#define         MGRM_color_list_3d(mode, object, sp_cfun, x, y, z, this_color) \
                MGR_color_eval_color(mode, object, sp_cfun, x, y, z, MMMNULL, MMMNULL, this_color);

#define         MGRM_color_surface(mode, object, sp_cfun, x, y, z, u, v, this_color) \
                MGR_color_eval_color(mode, object, sp_cfun, x, y, z, u, v, this_color);

/*
 * Deklarationen
 */
extern S_Pointer MGR_color_alloc_write_sp_color
                    (   MGRT_Color    *this_color
                    );

extern void      MGR_color_eval_color
                    (   long           mode,
                        MGRT_Object    *object,
                        S_Pointer      sp_cfun,
                        S_Pointer      x_coord,
                        S_Pointer      y_coord,
                        S_Pointer      z_coord,
                        S_Pointer      u_val,
                        S_Pointer      v_val,
                        MGRT_Color     *this_color
                    );

extern long     MGR_color_check_color
                   (   S_Pointer    sp_color,
                       long         n,
                       MGRT_Color   *this_color
                   );

#endif

long         MGR_convert_double_color
                (   double    d_color
                );

double       MGR_convert_long_color
                (   long    l_color
                );


#endif /* __MGR_color__ */

==> mupad-2.0.0.tgz: mupad/share/mmg/include/kernel/MGR_color.h <==
/*
 * Datei:      MGR_color.h
 *
 * Inhalt:     Diese Datei enth"alt die Deklaration aller
 *             Funktionen, die zur Evaluierung einer benut-
 *             zerdefinierten Farbfunktion implementiert
 *             wurden.
 *
 * Autor:      Thorsten Schulze
 *
 * Datum:      12.02.1994
 */

#ifndef __MGR_color__
#define __MGR_color__


/*
 * Konstanten
 */

#define        MGRC_CURVE_2D     0
#define        MGRC_CURVE_3D     1
#define        MGRC_SURFACE      2
#define        MGRC_LIST_2D      3
#define        MGRC_LIST_3D      4

#ifndef GRAPHIC

/*
 * Makros
 */

#define         MGRM_color_curve_2d(mode, object, sp_cfun, x, y, u, this_color) \
                MGR_color_eval_color(mode, object, sp_cfun, x, y, MMMNULL, u, MMMNULL, this_color);

#define         MGRM_color_list_2d(mode, object, sp_cfun, x, y, this_color) \
                MGR_color_eval_color(mode, object, sp_cfun, x, y, MMMNULL, MMMNULL, MMMNULL, this_color);

#define         MGRM_color_curve_3d(mode, object, sp_cfun, x, y, z, u, this_color) \
                MGR_color_eval_color(mode, object, sp_cfun, x, y, z, u, MMMNULL, this_color);

#define         MGRM_color_list_3d(mode, object, sp_cfun, x, y, z, this_color) \
                MGR_color_eval_color(mode, object, sp_cfun, x, y, z, MMMNULL, MMMNULL, this_color);

#define         MGRM_color_surface(mode, object, sp_cfun, x, y, z, u, v, this_color) \
                MGR_color_eval_color(mode, object, sp_cfun, x, y, z, u, v, this_color);

/*
 * Deklarationen
 */
extern S_Pointer MGR_color_alloc_write_sp_color
                    (   MGRT_Color    *this_color
                    );

extern void      MGR_color_eval_color
                    (   long           mode,
                        MGRT_Object    *object,
                        S_Pointer      sp_cfun,
                        S_Pointer      x_coord,
                        S_Pointer      y_coord,
                        S_Pointer      z_coord,
                        S_Pointer      u_val,
                        S_Pointer      v_val,
                        MGRT_Color     *this_color
                    );

extern long     MGR_color_check_color
                   (   S_Pointer    sp_color,
                       long         n,
                       MGRT_Color   *this_color
                   );

#endif

long         MGR_convert_double_color
                (   double    d_color
                );

double       MGR_convert_long_color
                (   long    l_color
                );


#endif /* __MGR_color__ */
